@@ -4,6 +4,7 @@ import pexpect
 from decorator import decorator
 from fabric.api import puts
 from fabric.colors import green
+from fabric.utils import error
 
 def this_func(level=1):
     frm = inspect.stack()[level]
@@ -23,6 +24,7 @@ def completed_ok(arg_output=[]):
         
 
 def local_run_expect(cmd, prompts, answers, logfile=sys.stdout):
+    puts(cmd)
     child = pexpect.spawn(
         cmd,
         timeout=1800,
@@ -36,3 +38,10 @@ def local_run_expect(cmd, prompts, answers, logfile=sys.stdout):
                 child.sendline(answers[i])
         except pexpect.EOF:
             break
+    child.close()
+    success = False
+    if child.exitstatus is not None:
+        if child.exitstatus == 0:
+            success = True
+    if not success:
+        error("Error in rsync subprocess: exit_code=%s; signal=%s" % (child.exitstatus, child.signalstatus))
